# This work is based upon CMFExternalFile, which was developed by
# Alan Runyan with contributions by Andy McKay, Kiran Jonnalagadda
# and PloneExternalFile developed by Florian Geier.
#
# CMFManagedFile extends CMFExternalFile to include a concept that
# can be found in PloneExternalFile where uploaded documents may be
# routed to specific directories or file systems.  This is specified by the
# user at upload time through the selection of pre-defined "repositories"
# that the site administrator would define and establish.
#
# The merger of CMFExternalFile and PloneExternalFile has been further
# extended to include some aspects of managing the external files on the
# file systems.  These include the automatic deletion of the file system files
# for deleted documents of the class CMFManagedFile governed by customizable
# and user selectable deletion policies, and the automatic movement of files
# from one file system repository to another based upon an edit action
# that includes the selection of a repository other than the repository
# in which the file is currently stored.
#
"""
$Id: config.py 1110 2005-03-01 21:03:00Z sidnei $
"""
import os
from Globals import INSTANCE_HOME
from zLOG import LOG, INFO

def log(msg):
    LOG('CMFManagedFile', INFO, msg)

DEFAULT_PATH = os.path.join(INSTANCE_HOME, 'var', 'managed_files')
DIR_MODE = 0750

DELETE_IMMEDIATE = 'Immediate'
DELETE_DEFERRED = 'Deferred'
DELETE_MANUAL = 'Manual'
TEMP_DOCUMENT = 'Temporary'
REUSED_FILENAME = '***Reused: '
GENERATE_POLICY = 'Generated'
ORIGINAL_POLICY = 'Original'

FS_RELATIVE = 'RelativePath'
FS_PHYSICAL = 'PhysicalPath'
FS_BASE = 'BasePath'
FS_PORTAL_TYPE = 'PortalType'

TOOL_NAME = 'portal_managed_files'

MAX_FILE_SIZE = 5 << 20

NET_MAPS = {}
# We can automagically map some shares to drives. Just uncomment the
# bits below and modify accordingly. Of course, this just makes sense
# if we are running on Windows.
# NET_MAPS = {'G:': (r'\\server\sharename', r'domain\user', r'userpassword')}

MAPPED_DRIVES = {}

# Make mapped drives for this service (process)
# Need to make this accessible so UI can view it
if os.name == 'nt':
    import traceback
    from cStringIO import StringIO
    try:
        import win32wnet, win32netcon
        for drive, (unc, login, passwd) in NET_MAPS.items():
            win32wnet.WNetAddConnection2(win32netcon.RESOURCETYPE_DISK,
                                         drive, unc, None, login, passwd, 0)
        MAPPED_DRIVES[drive] = unc
    except Exception, e:
        out = StringIO()
        traceback.print_exc(file=out)
        log(out.getvalue())
