# This work is based upon CMFExternalFile, which was developed by
# Alan Runyan with contributions by Andy McKay, Kiran Jonnalagadda
# and PloneExternalFile developed by Florian Geier.
#
# CMFManagedFile extends CMFExternalFile to include a concept that
# can be found in PloneExternalFile where uploaded documents may be
# routed to specific directories or file systems.  This is specified by the
# user at upload time through the selection of pre-defined "repositories"
# that the site administrator would define and establish.
#
# The merger of CMFExternalFile and PloneExternalFile has been further
# extended to include some aspects of managing the external files on the
# file systems.  These include the automatic deletion of the file system files
# for deleted documents of the class CMFManagedFile governed by customizable
# and user selectable deletion policies, and the automatic movement of files
# from one file system repository to another based upon an edit action
# that includes the selection of a repository other than the repository
# in which the file is currently stored.
#
"""
$Id: base.py 572 2004-12-08 23:36:34Z sidnei $
"""

import os
import shutil
from Testing import ZopeTestCase
from Testing.ZopeTestCase import doctest
from Products.CMFPlone.tests import PloneTestCase

ZopeTestCase.installProduct('ExternalFile')
ZopeTestCase.installProduct('ExternalEditor')
ZopeTestCase.installProduct('CMFManagedFile')

from zExceptions.ExceptionFormatter import format_exception
from ZPublisher.HTTPResponse import HTTPResponse

# Silence Plone's handling of exceptions
orig_exception = HTTPResponse.exception
def exception(self, **kw):
    def tag_search(*args):
        return False
    kw['tag_search'] = tag_search
    return orig_exception(self, **kw)

orig_setBody = HTTPResponse.setBody
def setBody(self, *args, **kw):
    kw['is_error'] = 0
    if isinstance(args[0], tuple) and len(args[0]) == 2:
        title, body = args[0]
        args = (body,) + args[1:]
    return orig_setBody(self, *args, **kw)

def _traceback(self, t, v, tb, as_html=1):
    return ''.join(format_exception(t, v, tb, as_html=as_html))

HTTPResponse._error_format = 'text/plain'
HTTPResponse._traceback = _traceback
HTTPResponse.exception = exception
HTTPResponse.setBody = setBody

from Products.CMFCore.utils import getToolByName
from Products.CMFManagedFile.config import TOOL_NAME



class TestCase(PloneTestCase.PloneTestCase):

    _products = ('CMFManagedFile',)
    _default_type = 'ManagedFile'

    def afterSetUp(self):
        self.qi = getToolByName(self.portal, 'portal_quickinstaller')
        for p in self._products:
            self.qi.installProduct(p)
        self.tool = getToolByName(self.portal, TOOL_NAME)

    def makeOne(self, **kw):
        kind = kw.get('kind', self._default_type)
        if kw.has_key('kind'):
            del kw['kind']
        context = kw.get('context', self.portal)
        if kw.has_key('context'):
            del kw['context']
        context.invokeFactory(kind, **kw)
        return context._getOb(kw['id'])

class FunctionalTestCase(ZopeTestCase.Functional, TestCase): pass

class FunctionalTestMixin:
    _super = None

    def setUp(self):
        self.cleanups = []
        self.cleanup_dirs = []
        self._super.setUp(self)

    def tearDown(self):
        self._super.tearDown(self)
        for fname in self.cleanups:
            try:
                os.remove(fname)
            except OSError:
                pass
        for dname in self.cleanup_dirs:
            try:
                shutil.rmtree(dname, ignore_errors=True)
            except OSError:
                pass

class FunctionalTest(FunctionalTestMixin, FunctionalTestCase):
    _super = FunctionalTestCase
